@@ -14,11 +14,24 @@ def get_params_for_search(request, Obj, ObjForm, search_fields, result_fields, \
     datetimefield_exists = False
     booleanfield_exists = False
     for field in search_fields:
+        _internal_type = False
+        this_is_a_modificator = False
+        if type(field) == tuple:
+            this_is_a_modificator = {'treat_as': 'in'}
+            (field, _internal_type) = field
+            if not field in relational_obj_values:
+                relational_obj_values[field] = Obj.objects.filter().values_list(field, field).distinct().order_by(field)
         remaining = {}
         remaining['label'] = field
+        if this_is_a_modificator:
+            remaining['modificator'] = this_is_a_modificator
         if field in translations:
             remaining['label'] = translations[field]
-        internal_type = Obj._meta.get_field(field).get_internal_type()
+        if _internal_type:
+            internal_type = _internal_type
+        else:
+            internal_type = Obj._meta.get_field(field).get_internal_type()
+        print(internal_type)
         if internal_type in ('IntegerField', 'FloatField', 'DecimalField'):
             fields.append((field, 'number', 'ltgt', remaining))
             charfield_exists = True
@@ -40,6 +53,8 @@ def get_params_for_search(request, Obj, ObjForm, search_fields, result_fields, \
     class_name = Obj._meta.object_name
     class_name_lower = class_name.lower()
     ajax_url = reverse('ajax_get_%s_list' % class_name.lower())
+    print(fields, class_name, class_name_lower, ajax_url, charfield_exists, \
+            datetimefield_exists, booleanfield_exists)
     return (fields, class_name, class_name_lower, ajax_url, charfield_exists, \
             datetimefield_exists, booleanfield_exists)
 
