@@ -493,7 +493,10 @@ def ajax_get_general_obj_list(request, Obj, ObjForm, search_fields=(), \
                             dt[field[0]] = False
                 elif field[1] == 'relation':
                     if any(get_fields[field[0]]):
-                        dt['%s__id__in' % field[0]] = get_fields[field[0]]
+                        if 'modificator' in field[3]:
+                            dt['%s__in' % field[0]] = get_fields[field[0]]
+                        else:
+                            dt['%s__id__in' % field[0]] = get_fields[field[0]]
             ret_dic['objects'] = Obj.objects.filter(**dt)
             print('dt = %s' % dt)
         else:
